/*********
*
* This file is part of BibleTime's source code, http://www.bibletime.info/.
*
* Copyright 1999-2008 by the BibleTime developers.
* The BibleTime source code is licensed under the GNU General Public License version 2.0.
*
**********/

#include "frontend/display/cwritedisplay.h"

#include "frontend/displaywindow/cwritewindow.h"


CWriteDisplay::CWriteDisplay( CWriteWindow* writeWindow ) : CDisplay(writeWindow) {
    // Intentionally empty
}

CWriteDisplay::~CWriteDisplay() {
    // Intentionally empty
}
